@@ -150,8 +150,11 @@ def xml_formatter_main():
         parser.print_help()
         sys.exit(0)
 
-    signal.signal(signal.SIGALRM, interrupted)
-    signal.alarm(TIMEOUT)
+    try :
+        signal.signal(signal.SIGALRM, interrupted)
+        signal.alarm(TIMEOUT)
+    except :
+        pass
     xmlinput = sys.stdin.read()
     signal.alarm(0)
 
@@ -173,11 +176,17 @@ def xml_formatter_main():
     try:
         doc = xmltodict.parse(xmlinput)
     except:
-        print("\n".join([str(lno) + " : " + ln for lno, ln in enumerate(xmlinput.splitlines())]), file=sys.stderr, flush=True)
-        print("# error parsing XML contents : {}".format(
-            traceback.format_exc().splitlines()[-1]),
-              file=sys.stderr,
-              flush=True)
+        xmldata = [str(lno) + " : " + ln for lno, ln in enumerate(xmlinput.splitlines())]
+        errmsg = traceback.format_exc().splitlines()[-1]
+        m = re.search(r"not well-formed \(invalid token\): line (\d+),",errmsg) 
+        if m :
+            lno = int(m.group(1))
+            begin = max(lno-3,0)
+            end = lno+4
+            print("\n".join(xmldata[begin:end]),file=sys.stderr,flush=True)
+        else :
+            print("{}".format("\n".join(xmldata)), file=sys.stderr, flush=True)
+        print("# error parsing XML contents : {}".format(errmsg), file=sys.stderr, flush=True)
         return -1
     if "resultset" not in doc:
         print("# not valid resultset XML contents :",
